# -*- coding: utf-8 -*-

# @Time  : 2022/6/4 21:42
# @Author : boliqq07
# @Software: PyCharm
# @License: MIT License

"""
This is a template for properties extract.

1. core function (force)
2. class with method from (files, or path).
3. processing batch
4. _CLICommand. (force)
5. argparse. (force)
"""
